==> views_slideshow_swiper-7.x-1.2.tar.gz: views_slideshow_swiper/js/views_slideshow_swiper.js <==
(function ($) {
  // @todo convert to use Drupal.behaviors
  // @todo add configuration options

  // Register callback to save references to Swiper instances. Allows
  // Views Slideshow controls to affect the slider
  function views_slideshow_swiper_register(fullId, slider) {
    Drupal.viewsSlideshowSwiper.active = Drupal.viewsSlideshowSwiper.active || {};
    Drupal.viewsSlideshowSwiper.active[fullId] = slider;
  }

  Drupal.settings.viewsSlideshowSwiperCallbacks = {
    'onInit': ['swiper'],
    'onSlideChangeStart': ['swiper'],
    'onSlideChangeEnd': ['swiper'],
    'onTransitionStart': ['swiper'],
    'onTransitionEnd': ['swiper'],
    'onTouchStart': ['swiper', 'event'],
    'onTouchMove': ['swiper', 'event'],
    'onTouchMoveOpposite': ['swiper', 'event'],
    'onSliderMove': ['swiper', 'event'],
    'onTouchEnd': ['swiper', 'event'],
    'onClick': ['swiper', 'event'],
    'onTap': ['swiper', 'event'],
    'onDoubleTap': ['swiper', 'event'],
    'onImagesReady': ['swiper'],
    'onProgress': ['swiper', 'progress'],
    'onReachBeginning': ['swiper'],
    'onReachEnd': ['swiper'],
    'onDestroy': ['swiper'],
    'onSetTranslate': ['swiper', 'translate'],
    'onSetTransition': ['swiper', 'transition'],
    'onAutoplayStart': ['swiper'],
    'onAutoplayStop': ['swiper'],
    'onLazyImageLoad': ['swiper', 'slide', 'image'],
    'onLazyImageReady': ['swiper', 'slide', 'image'],
  };

  Drupal.behaviors.viewsSlideshowSwiper = {
    attach: function (context) {
      $('.views_slideshow_swiper_main:not(.views_slideshow_swiper-processed)', context).addClass('views_slideshow_swiper-processed').each(function() {
        // Get the ID of the slideshow
        var fullId = '#' + $(this).attr('id');

        // Create settings container
        var settings = Drupal.settings.viewsSlideshowSwiper[fullId];

        //~ var createFunction = (function(args, body) {
          //~ function F(args) {
            //~ return Function.apply(this, args);
          //~ }
          //~ F.prototype = Function.prototype;

          //~ return function(args, body) {
            //~ return new F(args.concat(body));
          //~ }
        //~ })();

        var settingSuffix = "CallbackFunction";
        Object.keys(settings.options).filter(function(value) {
          console.log(value.substring(value.substring - settingSuffix.length));
          return value.substring(value.length - settingSuffix.length) === settingSuffix;
        }).forEach(function(key) {
          var parameter = key.substring(0, this.length - settingSuffix.length);
          console.log(key)
          console.log(parameter)
//          settings.options[parameter] = createFunction(Drupal.settings.viewsSlideshowSwiperCallbacks[parameter], settings.options[key]);
          delete settings.options[key];
        });

        settings.loaded = false;

        Drupal.viewsSlideshowSwiper.load(fullId);
      });
    }
  };

function onInit(swiper) {
  controls = $(swiper.fullId).siblings('.views-slideshow-controls-top, ..views-slideshow-controls-bottom');
  if ($controls > 0) {
    controls = $controls.shift();
  } else {
    controls = $(contentToBeInserted).insertBefore('#' + swiper.fullId);
  }
  $(controls).html(swiper.activeIndex + 1 + " of " + swiper.length);
}
  // Initialize the swiperjs object
  Drupal.viewsSlideshowSwiper = Drupal.viewsSlideshowSwiper || {};

  // Load mapping from Views Slideshow to Swiper
  Drupal.viewsSlideshowSwiper.load = function(fullId) {
    var settings = Drupal.settings.viewsSlideshowSwiper[fullId];

    // Ensure the slider isn't already loaded
    if (!settings.loaded) {
      settings.swiper = new Swiper(settings.id_prefix + settings.vss_id, settings.options);
      settings.loaded = true;
      settings.swiper.fullId = fullId;
    }
  };

  //~ Drupal.viewsSlideshowSwiper.transitionBegin = function (options) {
  //~ }

  //~ Drupal.viewsSlideshowSwiper.transitionEnd = function (options) {
  //~ }

  Drupal.viewsSlideshowSwiper.goToSlide = function (options) {
    Drupal.settings.viewsSlideshowSwiper[options.slideshowID].swiper.slideTo(options.slideNum);
  };

  // Pause mapping from Views Slideshow to Swiper
  Drupal.viewsSlideshowSwiper.pause = function (options) {
    Drupal.settings.viewsSlideshowSwiper[options.slideshowID].swiper.stopAutoplay();
  };

  // Play mapping from Views Slideshow to Swiper
  Drupal.viewsSlideshowSwiper.play = function (options) {
    Drupal.settings.viewsSlideshowSwiper[options.slideshowID].swiper.startAutoplay();
  };
  
  Drupal.viewsSlideshowSwiper.nextSlide = function (options) {
    Drupal.settings.viewsSlideshowSwiper[options.slideshowID].swiper.slideNext();
  };
  
  Drupal.viewsSlideshowSwiper.previousSlide = function (options) {
    Drupal.settings.viewsSlideshowSwiper[options.slideshowID].swiper.slidePrev();
  };
  // @todo add support for jquery mobile page init
})(jQuery);

==> views_slideshow_swiper-7.x-1.3.tar.gz: views_slideshow_swiper/js/views_slideshow_swiper.js <==
(function ($) {
  // @todo convert to use Drupal.behaviors
  // @todo add configuration options

  // Register callback to save references to Swiper instances. Allows
  // Views Slideshow controls to affect the slider
  function views_slideshow_swiper_register(fullId, slider) {
    Drupal.viewsSlideshowSwiper.active = Drupal.viewsSlideshowSwiper.active || {};
    Drupal.viewsSlideshowSwiper.active[fullId] = slider;
  }

  Drupal.settings.viewsSlideshowSwiperCallbacks = {
    'onInit': ['swiper'],
    'onSlideChangeStart': ['swiper'],
    'onSlideChangeEnd': ['swiper'],
    'onTransitionStart': ['swiper'],
    'onTransitionEnd': ['swiper'],
    'onTouchStart': ['swiper', 'event'],
    'onTouchMove': ['swiper', 'event'],
    'onTouchMoveOpposite': ['swiper', 'event'],
    'onSliderMove': ['swiper', 'event'],
    'onTouchEnd': ['swiper', 'event'],
    'onClick': ['swiper', 'event'],
    'onTap': ['swiper', 'event'],
    'onDoubleTap': ['swiper', 'event'],
    'onImagesReady': ['swiper'],
    'onProgress': ['swiper', 'progress'],
    'onReachBeginning': ['swiper'],
    'onReachEnd': ['swiper'],
    'onDestroy': ['swiper'],
    'onSetTranslate': ['swiper', 'translate'],
    'onSetTransition': ['swiper', 'transition'],
    'onAutoplayStart': ['swiper'],
    'onAutoplayStop': ['swiper'],
    'onLazyImageLoad': ['swiper', 'slide', 'image'],
    'onLazyImageReady': ['swiper', 'slide', 'image'],
  };

  Drupal.behaviors.viewsSlideshowSwiper = {
    attach: function (context) {
      $('.views_slideshow_swiper_main:not(.views_slideshow_swiper-processed)', context).addClass('views_slideshow_swiper-processed').each(function() {
        // Get the ID of the slideshow
        var fullId = '#' + $(this).attr('id');

        // Create settings container
        var settings = Drupal.settings.viewsSlideshowSwiper[fullId];
        if ('autoplay' in settings.options && (settings.options['autoplay'] === 0 || settings.options['autoplay'] === '')) {
          settings.options.splice('autoplya', 1);
        }

        var createFunction = (function(args, body) {
          function F(args) {
            return Function.apply(this, args);
          }
          F.prototype = Function.prototype;

          return function(args, body) {
            return new F(args.concat(body));
          }
        })();

        var settingSuffix = "CallbackFunction";
        Object.keys(settings.options).filter(function(value) {
          return value.substring(value.length - settingSuffix.length) === settingSuffix;
        }).forEach(function(key) {
          var parameter = key.substring(0, this.length - settingSuffix.length);
          //~ settings.options[parameter] = createFunction(Drupal.settings.viewsSlideshowSwiperCallbacks[parameter], settings.options[key]);
          delete settings.options[key];
        });

        settings.loaded = false;

        Drupal.viewsSlideshowSwiper.load(fullId);
      });
    }
  };

  // Initialize the swiperjs object
  Drupal.viewsSlideshowSwiper = Drupal.viewsSlideshowSwiper || {};

  // Load mapping from Views Slideshow to Swiper
  Drupal.viewsSlideshowSwiper.load = function(fullId) {
    var settings = Drupal.settings.viewsSlideshowSwiper[fullId];

    // Ensure the slider isn't already loaded
    if (!settings.loaded) {
      settings.swiper = new Swiper(settings.id_prefix + settings.vss_id, settings.options);
      settings.loaded = true;
      settings.swiper.fullId = fullId;
    }
  };

  //~ Drupal.viewsSlideshowSwiper.transitionBegin = function (options) {
  //~ }

  //~ Drupal.viewsSlideshowSwiper.transitionEnd = function (options) {
  //~ }

  Drupal.viewsSlideshowSwiper.goToSlide = function (options) {
    Drupal.settings.viewsSlideshowSwiper[options.slideshowID].swiper.slideTo(options.slideNum);
  };

  // Pause mapping from Views Slideshow to Swiper
  Drupal.viewsSlideshowSwiper.pause = function (options) {
    Drupal.settings.viewsSlideshowSwiper[options.slideshowID].swiper.stopAutoplay();
  };

  // Play mapping from Views Slideshow to Swiper
  Drupal.viewsSlideshowSwiper.play = function (options) {
    Drupal.settings.viewsSlideshowSwiper[options.slideshowID].swiper.startAutoplay();
  };
  
  Drupal.viewsSlideshowSwiper.nextSlide = function (options) {
    Drupal.settings.viewsSlideshowSwiper[options.slideshowID].swiper.slideNext();
  };
  
  Drupal.viewsSlideshowSwiper.previousSlide = function (options) {
    Drupal.settings.viewsSlideshowSwiper[options.slideshowID].swiper.slidePrev();
  };
  // @todo add support for jquery mobile page init
})(jQuery);
